@@ -70,6 +70,7 @@ static void     trash_applet_change_background  (PanelApplet     *panel_applet,
 						 PanelAppletBackgroundType type,
 						 GdkColor        *colour,
 						 GdkPixmap       *pixmap);
+static void trash_applet_theme_change (GtkIconTheme *icon_theme, gpointer data);
 
 static void trash_applet_do_empty    (BonoboUIComponent *component,
 				      TrashApplet       *applet,
@@ -141,9 +142,6 @@ trash_applet_init (TrashApplet *applet)
 		applet->orient = GTK_ORIENTATION_HORIZONTAL;
 		break;
 	}
-	applet->tooltips = gtk_tooltips_new ();
-	g_object_ref (applet->tooltips);
-	gtk_object_sink (GTK_OBJECT (applet->tooltips));
 
 	applet->image = gtk_image_new ();
 	gtk_container_add (GTK_CONTAINER (applet), applet->image);
@@ -180,6 +178,11 @@ trash_applet_init (TrashApplet *applet)
                            GTK_DEST_DEFAULT_ALL,
                            drop_types, n_drop_types,
                            GDK_ACTION_MOVE);
+
+  /* handle icon theme changes */
+  g_signal_connect (gtk_icon_theme_get_default (),
+		    "changed", G_CALLBACK (trash_applet_theme_change),
+		    applet);        
 }
 
 static void
@@ -188,9 +191,6 @@ trash_applet_destroy (GtkObject *object)
 	TrashApplet *applet = TRASH_APPLET (object);
 	
 	applet->image = NULL;
-	if (applet->tooltips)
-		g_object_unref (applet->tooltips);
-	applet->tooltips = NULL;
 
 	if (applet->monitor_signal_id)
 		g_signal_handler_disconnect (applet->monitor,
@@ -405,8 +405,7 @@ trash_applet_update (gpointer user_data)
 						applet->item_count), 
 						    applet->item_count);
 		}
-		gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet),
-				      tip_text, NULL);
+		gtk_widget_set_tooltip_text (GTK_WIDGET (applet), tip_text);
 		g_free (tip_text);
 	}
 
@@ -464,6 +463,13 @@ trash_applet_queue_update (TrashApplet *applet)
 	}
 }
 
+static void
+trash_applet_theme_change (GtkIconTheme *icon_theme, gpointer data)
+{
+  TrashApplet *applet = TRASH_APPLET (data);
+  trash_applet_update (applet);
+}
+
 /* TODO - Must HIGgify this dialog */
 static void
 error_dialog (TrashApplet *applet, const gchar *error, ...)
@@ -508,22 +514,20 @@ update_transfer_callback (GnomeVFSAsyncHandle *handle,
 	if (progress_info->files_total != 0) {
 		GtkWidget *progressbar;
 		gdouble fraction;
-		gchar *index, *total;
 		gchar *progress_message;
 
 		progressbar = glade_xml_get_widget (xml, "progressbar");
 
 		fraction = (gulong) progress_info->file_index / (gulong) progress_info->files_total;
-
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progressbar), fraction);
 
-		index = g_strdup_printf ("%i", progress_info->file_index);
-		total = g_strdup_printf ("%i", progress_info->files_total);
-		progress_message = g_strdup_printf (_("Removing item %s of %s"), index, total);
-		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progressbar), progress_message);
+		progress_message = g_strdup_printf (_("Removing item %d of %d"),
+						    progress_info->file_index,
+						    progress_info->files_total);
+		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progressbar),
+					   progress_message);
+
 		g_free (progress_message);
-		g_free (index);
-		g_free (total);
 	}
 
 	if (progress_info->source_name != NULL) {
@@ -542,7 +546,9 @@ update_transfer_callback (GnomeVFSAsyncHandle *handle,
 		from_location = gnome_vfs_uri_extract_dirname (uri);
 
 		short_name = gnome_vfs_uri_extract_short_name (uri);
-		file = g_strdup_printf (_("<i>Removing: %s</i>"), short_name);
+		file = g_strdup_printf ("<i>%s %s</i>",
+                                        _("Removing:"),
+                                        short_name);
 		g_free (short_name);
 
 		gtk_label_set_markup (GTK_LABEL (location_label), from_location);
@@ -669,6 +675,8 @@ trash_applet_open_folder (BonoboUIComponent *component,
 			  TrashApplet       *applet,
 			  const gchar       *cname)
 {
+	GdkScreen *screen;
+
 	/* Open the "trash:" URI with gnome-open */
 	gchar *argv[] = { "gnome-open", "trash:", NULL };
 	GError *err = NULL;
@@ -676,12 +684,13 @@ trash_applet_open_folder (BonoboUIComponent *component,
 
         g_return_if_fail (TRASH_IS_APPLET (applet));
 
-	res = g_spawn_async (NULL,
-			     argv, NULL,
-			     G_SPAWN_SEARCH_PATH,
-			     NULL, NULL,
-			     NULL,
-			     &err);
+	screen = gtk_widget_get_screen (GTK_WIDGET (applet));
+	res = gdk_spawn_on_screen (screen, NULL,
+			           argv, NULL,
+			           G_SPAWN_SEARCH_PATH,
+			           NULL, NULL,
+			           NULL,
+			           &err);
 	
 	if (! res) {
 		error_dialog (applet, _("Error while spawning nautilus:\n%s"),
@@ -731,7 +740,6 @@ trash_applet_show_about (BonoboUIComponent *component,
 
 	gtk_show_about_dialog
 		(NULL,
-		 "name", _("Trash Applet"),
 		 "version", VERSION,
 		 "copyright", "Copyright \xC2\xA9 2004 Michiel Sikkes",
 		 "comments", _("A GNOME trash bin that lives in your panel. "
@@ -956,6 +964,8 @@ main (int argc, char *argv [])
                             GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,
                             GNOME_PROGRAM_STANDARD_PROPERTIES,
                             NULL);
+	g_set_application_name (_("Trash Applet"));
+
         return panel_applet_factory_main
 		("OAFIID:GNOME_Panel_TrashApplet_Factory", TRASH_TYPE_APPLET,
 		 trash_applet_factory, NULL);
